@@ -1,7 +1,11 @@
-# == title
+
 # Open the online website of package dependency analysis
 #
-open_website = function() {
+#
+# == details
+# The analyis is based on all CRAN/Bioconductor packages retrieved on 2021-10-28.
+#
+dependency_website = function() {
 
 	pkgs = c("knitr", "igraph", "ggrepel", "callr", "Rook")
 	for(p in pkgs) {
@@ -9,5 +13,7 @@ open_website = function() {
 			stop(paste0("Package ", p, " is needed for the website, please install it from CRAN."))
 		}
 	}
+
 	callr::rscript(system.file("website", "app.R", package = "pkgndep"))
 }
+
